@@ -33,14 +33,13 @@ describe 'murano::db::postgresql_cfapi' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :concat_basedir => '/var/lib/puppet/concat'
+          # puppet-postgresql requires the service_provider fact provided by
+          # puppetlabs-postgresql.
+          :service_provider => 'systemd'
         }))
       end
 
-      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
-      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
-        it_configures 'murano::db::postgresql_cfapi'
-      end
+      it_configures 'murano::db::postgresql_cfapi'
     end
   end
 
